==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1NetworkPolicyIngressRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NetworkPolicyIngressRuleFluent<A extends V1NetworkPolicyIngressRuleFluent<A>> extends Fluent<A>{


    public A addToFrom(int index,V1NetworkPolicyPeer item);
    public A setToFrom(int index,V1NetworkPolicyPeer item);
    public A addToFrom(V1NetworkPolicyPeer... items);
    public A addAllToFrom(Collection<V1NetworkPolicyPeer> items);
    public A removeFromFrom(V1NetworkPolicyPeer... items);
    public A removeAllFromFrom(Collection<V1NetworkPolicyPeer> items);
    
/**
 * This method has been deprecated, please use method buildFrom instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPeer> getFrom();
    public List<V1NetworkPolicyPeer> buildFrom();
    public V1NetworkPolicyPeer buildFrom(int index);
    public V1NetworkPolicyPeer buildFirstFrom();
    public V1NetworkPolicyPeer buildLastFrom();
    public V1NetworkPolicyPeer buildMatchingFrom(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public A withFrom(List<V1NetworkPolicyPeer> from);
    public A withFrom(V1NetworkPolicyPeer... from);
    public Boolean hasFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> addNewFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> addNewFromLike(V1NetworkPolicyPeer item);
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> setNewFromLike(int index,V1NetworkPolicyPeer item);
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editFrom(int index);
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editFirstFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editLastFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editMatchingFrom(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public A addToPorts(int index,V1NetworkPolicyPort item);
    public A setToPorts(int index,V1NetworkPolicyPort item);
    public A addToPorts(V1NetworkPolicyPort... items);
    public A addAllToPorts(Collection<V1NetworkPolicyPort> items);
    public A removeFromPorts(V1NetworkPolicyPort... items);
    public A removeAllFromPorts(Collection<V1NetworkPolicyPort> items);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPort> getPorts();
    public List<V1NetworkPolicyPort> buildPorts();
    public V1NetworkPolicyPort buildPort(int index);
    public V1NetworkPolicyPort buildFirstPort();
    public V1NetworkPolicyPort buildLastPort();
    public V1NetworkPolicyPort buildMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public A withPorts(List<V1NetworkPolicyPort> ports);
    public A withPorts(V1NetworkPolicyPort... ports);
    public Boolean hasPorts();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPort();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPortLike(V1NetworkPolicyPort item);
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> setNewPortLike(int index,V1NetworkPolicyPort item);
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editPort(int index);
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editFirstPort();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editLastPort();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);

    public interface FromNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPeerFluent<V1NetworkPolicyIngressRuleFluent.FromNested<N>>{

        
    public N and();    public N endFrom();
}
    public interface PortsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPortFluent<V1NetworkPolicyIngressRuleFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NetworkPolicyIngressRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NetworkPolicyIngressRuleFluent<A extends V1NetworkPolicyIngressRuleFluent<A>> extends Fluent<A>{


    public A addToFrom(int index,V1NetworkPolicyPeer item);
    public A setToFrom(int index,V1NetworkPolicyPeer item);
    public A addToFrom(V1NetworkPolicyPeer... items);
    public A addAllToFrom(Collection<V1NetworkPolicyPeer> items);
    public A removeFromFrom(V1NetworkPolicyPeer... items);
    public A removeAllFromFrom(Collection<V1NetworkPolicyPeer> items);
    
/**
 * This method has been deprecated, please use method buildFrom instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPeer> getFrom();
    public List<V1NetworkPolicyPeer> buildFrom();
    public V1NetworkPolicyPeer buildFrom(int index);
    public V1NetworkPolicyPeer buildFirstFrom();
    public V1NetworkPolicyPeer buildLastFrom();
    public V1NetworkPolicyPeer buildMatchingFrom(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public Boolean hasMatchingFrom(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public A withFrom(List<V1NetworkPolicyPeer> from);
    public A withFrom(V1NetworkPolicyPeer... from);
    public Boolean hasFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> addNewFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> addNewFromLike(V1NetworkPolicyPeer item);
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> setNewFromLike(int index,V1NetworkPolicyPeer item);
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editFrom(int index);
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editFirstFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editLastFrom();
    public V1NetworkPolicyIngressRuleFluent.FromNested<A> editMatchingFrom(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPeerBuilder> predicate);
    public A addToPorts(int index,V1NetworkPolicyPort item);
    public A setToPorts(int index,V1NetworkPolicyPort item);
    public A addToPorts(V1NetworkPolicyPort... items);
    public A addAllToPorts(Collection<V1NetworkPolicyPort> items);
    public A removeFromPorts(V1NetworkPolicyPort... items);
    public A removeAllFromPorts(Collection<V1NetworkPolicyPort> items);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NetworkPolicyPort> getPorts();
    public List<V1NetworkPolicyPort> buildPorts();
    public V1NetworkPolicyPort buildPort(int index);
    public V1NetworkPolicyPort buildFirstPort();
    public V1NetworkPolicyPort buildLastPort();
    public V1NetworkPolicyPort buildMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public Boolean hasMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);
    public A withPorts(List<V1NetworkPolicyPort> ports);
    public A withPorts(V1NetworkPolicyPort... ports);
    public Boolean hasPorts();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPort();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> addNewPortLike(V1NetworkPolicyPort item);
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> setNewPortLike(int index,V1NetworkPolicyPort item);
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editPort(int index);
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editFirstPort();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editLastPort();
    public V1NetworkPolicyIngressRuleFluent.PortsNested<A> editMatchingPort(io.kubernetes.client.fluent.Predicate<V1NetworkPolicyPortBuilder> predicate);

    public interface FromNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPeerFluent<V1NetworkPolicyIngressRuleFluent.FromNested<N>>{

        
    public N and();    public N endFrom();
}
    public interface PortsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NetworkPolicyPortFluent<V1NetworkPolicyIngressRuleFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}


}
